@@ -35,7 +35,7 @@ class MarkdownHTTPRequestHandler(BaseHTTPRequestHandler):
             for entry in os.listdir(full_path):
                 content.append(
                     '<div><a href="{}">{}</a>'.format(
-                        os.path.join(path, entry),
+                        entry,  # os.path.join(path, entry),
                         entry
                     )
                 )
@@ -59,8 +59,7 @@ class MarkdownHTTPRequestHandler(BaseHTTPRequestHandler):
         self.send_header("Content-type", self.content_type)
 
         if last_modified is not None:
-            self.send_header("Last-Modified",
-                             self.date_time_string(last_modified))
+            self.send_header("Last-Modified", self.date_time_string(last_modified))
 
         self.send_header("Content-Length", len(text))
         self.end_headers()
